Task: VisDial
==============
Description: Task which requires agents to hold a meaningful dialog about visual content. From Das et al. '16. 

Link: https://arxiv.org/abs/1611.08669

Tags: #VisDial, #All, #Visual

